#[non_exhaustive]pub struct WiFiCellular {
pub confidence_percent: i32,
}Expand description
Configuration for WiFi and cellular location payloads.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.confidence_percent: i32Confidence level for WiFi and cellular position estimates, expressed as a percentage. Valid range: 50–99 inclusive. Defaults to 68 if not specified.
Implementations
Sourceimpl WiFiCellular
impl WiFiCellular
Sourcepub fn confidence_percent(&self) -> i32
pub fn confidence_percent(&self) -> i32
Confidence level for WiFi and cellular position estimates, expressed as a percentage. Valid range: 50–99 inclusive. Defaults to 68 if not specified.
Sourceimpl WiFiCellular
impl WiFiCellular
Sourcepub fn builder() -> WiFiCellularBuilder
pub fn builder() -> WiFiCellularBuilder
Creates a new builder-style object to manufacture WiFiCellular.